@@ -2,7 +2,7 @@
 #ifndef UNICODE__JAPANESE_H__
 #define UNICODE__JAPANESE_H__
 
-/* $Id: Japanese.h,v 1.24 2005/09/28 13:17:03 hio Exp $ */
+/* $Id: Japanese.h,v 1.25 2006/04/14 05:18:55 pho Exp $ */
 
 #if !defined(__cplusplus) && !defined(bool)
 #define bool char
@@ -60,6 +60,9 @@ extern "C"
   SV* xs_getcode(SV* sv_str);
   int xs_getcode_list(SV* sv_str);
 
+  /* utf-8 validation (utf8.c) */
+  SV* xs_validate_utf8(SV* sv_str);
+
   /* sjis<=>eucjp, sjis<=>jis */
   SV* xs_sjis_eucjp(SV* sv_str);
   SV* xs_eucjp_sjis(SV* sv_str);
